#!/bin/bash
# Copyright:	None.  This script has been placed in the public domain
#		by its author, Ron Burkey.
# Filename:	TTP-meta.sh
# Purpose:	This script is part of the TeachToPod.sh group
#		of scripts (see http://www.sandroid.org/TeachToPod).  
#		This particular script adds metadata like lecture names
#		previously collected by the TTP-scrape.sh script to 
#		audio/video files previously ripped from Teaching Company
#		DVDs by the TTP-rip.sh script.
# Mod history:	2010-12-13 RSB	Wrote.

# Script to add metadata to m4v or mp3 files ripped from Teaching Company disks.
# This same script can be used for any such course, as long as the lectures
# have been ripped to files with names like NM.m4v (or NM.mp3), where N is the disk
# number and M is the lecture number on the disk and the characteristics 
# of the course are supplied in a file called titles.txt.  If there are more
# than 9 disks or more than 9 lectures per disk, then N or M should be 
# 2-digit numbers with leading zeros where necessary.
#
# The first 4 lines of titles.txt give the number of disks, the number of 
# lectures per disk, the name of the course, and the Teaching Company's 
# course-number.  The remainder of the file consists of the lecture names.  
# The easiest way to produce this file is to use the script TTP-scrape.sh to
# scrape the info from the Teaching Company's website. 
#
# The full usage is:
#	TTP-meta.sh [Audio]
#
# If Audio is absent, then m4v video files are assumed.  If Audio is present
# (the value can be anything non-blank), then mp3 audio files are assumed.
#
# Example: If all the folders containing the ripped m4v files are sub-folders
# of the folder containing scrape.sh and meta.sh, we might do something 
# like the following:
#
#	cd "Masterworks of American Art"
#	../TTP-scrape.sh 1580
#	../TTP-meta.sh

Audio="$1"

# Read titles.txt into the titles[] array variable.
titles=
declare -a titles
mapfile -t titles <titles.txt
disks=${titles[0]}
perdisk=${titles[1]}
album="${titles[2]}"
course=${titles[3]}

# Sanity clause.
total=$((disks*perdisk))
if test "${titles[$((total+4-1))]}" == ""
then
	echo Not enough titles specified.
	exit 1
fi
if test "${titles[$total+4]}" != ""
then
	echo Too many titles specified.
	exit 1
fi

# Loop on the lectures.
k=4
for n in `seq -w 1 $disks`
do
	for m in `seq -w 1 $perdisk`
	do
		if test "$Audio" == ""
		then
			echo Processing $n$m.m4v ...
			AtomicParsley $n$m.m4v --artist "The Teaching Company" \
				--album "$album" --genre "Lectures" \
				--title "$course-$n$m ${titles[$k]}"
			mv $n$m-temp*.m4v $n$m.m4v
		else
			echo Processing $n$m.mp3 ...
			# Genre 101 is "Speech".
			id3v2 --artist "The Teaching Company" --album "$album" \
				--genre 101 --song "$course-$n$m ${titles[$k]}" $n$m.mp3
		fi
		k=$((k+1))
	done
done

